from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.TopoDS import *
from OCC.Core.GeomAbs import *
from OCC.Core.Geom2d import *
from OCC.Core.TopTools import *
from OCC.Core.Adaptor3d import *
from OCC.Core.Geom import *
from OCC.Core.BRepTools import *
from OCC.Core.TopLoc import *


class BRepLib_EdgeError(IntEnum):
	BRepLib_EdgeDone: int = ...
	BRepLib_PointProjectionFailed: int = ...
	BRepLib_ParameterOutOfRange: int = ...
	BRepLib_DifferentPointsOnClosedCurve: int = ...
	BRepLib_PointWithInfiniteParameter: int = ...
	BRepLib_DifferentsPointAndParameter: int = ...
	BRepLib_LineThroughIdenticPoints: int = ...
BRepLib_EdgeDone = BRepLib_EdgeError.BRepLib_EdgeDone
BRepLib_PointProjectionFailed = BRepLib_EdgeError.BRepLib_PointProjectionFailed
BRepLib_ParameterOutOfRange = BRepLib_EdgeError.BRepLib_ParameterOutOfRange
BRepLib_DifferentPointsOnClosedCurve = BRepLib_EdgeError.BRepLib_DifferentPointsOnClosedCurve
BRepLib_PointWithInfiniteParameter = BRepLib_EdgeError.BRepLib_PointWithInfiniteParameter
BRepLib_DifferentsPointAndParameter = BRepLib_EdgeError.BRepLib_DifferentsPointAndParameter
BRepLib_LineThroughIdenticPoints = BRepLib_EdgeError.BRepLib_LineThroughIdenticPoints

class BRepLib_ShellError(IntEnum):
	BRepLib_ShellDone: int = ...
	BRepLib_EmptyShell: int = ...
	BRepLib_DisconnectedShell: int = ...
	BRepLib_ShellParametersOutOfRange: int = ...
BRepLib_ShellDone = BRepLib_ShellError.BRepLib_ShellDone
BRepLib_EmptyShell = BRepLib_ShellError.BRepLib_EmptyShell
BRepLib_DisconnectedShell = BRepLib_ShellError.BRepLib_DisconnectedShell
BRepLib_ShellParametersOutOfRange = BRepLib_ShellError.BRepLib_ShellParametersOutOfRange

class BRepLib_ShapeModification(IntEnum):
	BRepLib_Preserved: int = ...
	BRepLib_Deleted: int = ...
	BRepLib_Trimmed: int = ...
	BRepLib_Merged: int = ...
	BRepLib_BoundaryModified: int = ...
BRepLib_Preserved = BRepLib_ShapeModification.BRepLib_Preserved
BRepLib_Deleted = BRepLib_ShapeModification.BRepLib_Deleted
BRepLib_Trimmed = BRepLib_ShapeModification.BRepLib_Trimmed
BRepLib_Merged = BRepLib_ShapeModification.BRepLib_Merged
BRepLib_BoundaryModified = BRepLib_ShapeModification.BRepLib_BoundaryModified

class BRepLib_WireError(IntEnum):
	BRepLib_WireDone: int = ...
	BRepLib_EmptyWire: int = ...
	BRepLib_DisconnectedWire: int = ...
	BRepLib_NonManifoldWire: int = ...
BRepLib_WireDone = BRepLib_WireError.BRepLib_WireDone
BRepLib_EmptyWire = BRepLib_WireError.BRepLib_EmptyWire
BRepLib_DisconnectedWire = BRepLib_WireError.BRepLib_DisconnectedWire
BRepLib_NonManifoldWire = BRepLib_WireError.BRepLib_NonManifoldWire

class BRepLib_FaceError(IntEnum):
	BRepLib_FaceDone: int = ...
	BRepLib_NoFace: int = ...
	BRepLib_NotPlanar: int = ...
	BRepLib_CurveProjectionFailed: int = ...
	BRepLib_ParametersOutOfRange: int = ...
BRepLib_FaceDone = BRepLib_FaceError.BRepLib_FaceDone
BRepLib_NoFace = BRepLib_FaceError.BRepLib_NoFace
BRepLib_NotPlanar = BRepLib_FaceError.BRepLib_NotPlanar
BRepLib_CurveProjectionFailed = BRepLib_FaceError.BRepLib_CurveProjectionFailed
BRepLib_ParametersOutOfRange = BRepLib_FaceError.BRepLib_ParametersOutOfRange

class breplib:
	@staticmethod
	def BuildCurve3d(E: TopoDS_Edge, Tolerance: Optional[float] = 1.0e-5, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C1, MaxDegree: Optional[int] = 14, MaxSegment: Optional[int] = 0) -> bool: ...
	@overload
	@staticmethod
	def BuildCurves3d(S: TopoDS_Shape, Tolerance: float, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C1, MaxDegree: Optional[int] = 14, MaxSegment: Optional[int] = 0) -> bool: ...
	@overload
	@staticmethod
	def BuildCurves3d(S: TopoDS_Shape) -> bool: ...
	@overload
	@staticmethod
	def BuildPCurveForEdgeOnPlane(theE: TopoDS_Edge, theF: TopoDS_Face) -> None: ...
	@overload
	@staticmethod
	def BuildPCurveForEdgeOnPlane(theE: TopoDS_Edge, theF: TopoDS_Face, aC2D: Geom2d_Curve) -> bool: ...
	@staticmethod
	def CheckSameRange(E: TopoDS_Edge, Confusion: Optional[float] = 1.0e-12) -> bool: ...
	@overload
	@staticmethod
	def EncodeRegularity(S: TopoDS_Shape, TolAng: Optional[float] = 1.0e-10) -> None: ...
	@overload
	@staticmethod
	def EncodeRegularity(S: TopoDS_Shape, LE: TopTools_ListOfShape, TolAng: Optional[float] = 1.0e-10) -> None: ...
	@overload
	@staticmethod
	def EncodeRegularity(E: TopoDS_Edge, F1: TopoDS_Face, F2: TopoDS_Face, TolAng: Optional[float] = 1.0e-10) -> None: ...
	@staticmethod
	def EnsureNormalConsistency(S: TopoDS_Shape, theAngTol: Optional[float] = 0.001, ForceComputeNormals: Optional[bool] = False) -> bool: ...
	@staticmethod
	def ExtendFace(theF: TopoDS_Face, theExtVal: float, theExtUMin: bool, theExtUMax: bool, theExtVMin: bool, theExtVMax: bool, theFExtended: TopoDS_Face) -> None: ...
	@overload
	@staticmethod
	def FindValidRange(theCurve: Adaptor3d_Curve, theTolE: float, theParV1: float, thePntV1: gp_Pnt, theTolV1: float, theParV2: float, thePntV2: gp_Pnt, theTolV2: float) -> Tuple[bool, float, float]: ...
	@overload
	@staticmethod
	def FindValidRange(theEdge: TopoDS_Edge) -> Tuple[bool, float, float]: ...
	@staticmethod
	def OrientClosedSolid(solid: TopoDS_Solid) -> bool: ...
	@overload
	@staticmethod
	def Plane(P: Geom_Plane) -> None: ...
	@overload
	@staticmethod
	def Plane() -> Geom_Plane: ...
	@overload
	@staticmethod
	def Precision(P: float) -> None: ...
	@overload
	@staticmethod
	def Precision() -> float: ...
	@staticmethod
	def ReverseSortFaces(S: TopoDS_Shape, LF: TopTools_ListOfShape) -> None: ...
	@overload
	@staticmethod
	def SameParameter(theEdge: TopoDS_Edge, Tolerance: Optional[float] = 1.0e-5) -> None: ...
	@overload
	@staticmethod
	def SameParameter(theEdge: TopoDS_Edge, theTolerance: float, IsUseOldEdge: bool) -> Tuple[TopoDS_Edge, float]: ...
	@overload
	@staticmethod
	def SameParameter(S: TopoDS_Shape, Tolerance: Optional[float] = 1.0e-5, forced: Optional[bool] = False) -> None: ...
	@overload
	@staticmethod
	def SameParameter(S: TopoDS_Shape, theReshaper: BRepTools_ReShape, Tolerance: Optional[float] = 1.0e-5, forced: Optional[bool] = False) -> None: ...
	@staticmethod
	def SameRange(E: TopoDS_Edge, Tolerance: Optional[float] = 1.0e-5) -> None: ...
	@staticmethod
	def SortFaces(S: TopoDS_Shape, LF: TopTools_ListOfShape) -> None: ...
	@staticmethod
	def UpdateEdgeTol(E: TopoDS_Edge, MinToleranceRequest: float, MaxToleranceToCheck: float) -> bool: ...
	@staticmethod
	def UpdateEdgeTolerance(S: TopoDS_Shape, MinToleranceRequest: float, MaxToleranceToCheck: float) -> bool: ...
	@staticmethod
	def UpdateInnerTolerances(S: TopoDS_Shape) -> None: ...
	@overload
	@staticmethod
	def UpdateTolerances(S: TopoDS_Shape, verifyFaceTolerance: Optional[bool] = False) -> None: ...
	@overload
	@staticmethod
	def UpdateTolerances(S: TopoDS_Shape, theReshaper: BRepTools_ReShape, verifyFaceTolerance: Optional[bool] = False) -> None: ...

class BRepLib_CheckCurveOnSurface:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theEdge: TopoDS_Edge, theFace: TopoDS_Face) -> None: ...
	def Curve(self) -> Geom_Curve: ...
	def ErrorStatus(self) -> int: ...
	def Init(self, theEdge: TopoDS_Edge, theFace: TopoDS_Face) -> None: ...
	def IsDone(self) -> bool: ...
	def MaxDistance(self) -> float: ...
	def MaxParameter(self) -> float: ...
	def PCurve(self) -> Geom2d_Curve: ...
	def PCurve2(self) -> Geom2d_Curve: ...
	def Perform(self, isTheMultyTheradDisabled: Optional[bool] = False) -> None: ...
	def Range(self) -> Tuple[float, float]: ...
	def Surface(self) -> Geom_Surface: ...

class BRepLib_Command:
	def Check(self) -> None: ...
	def IsDone(self) -> bool: ...

class BRepLib_FindSurface:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape, Tol: Optional[float] = -1, OnlyPlane: Optional[bool] = False, OnlyClosed: Optional[bool] = False) -> None: ...
	def Existed(self) -> bool: ...
	def Found(self) -> bool: ...
	def Init(self, S: TopoDS_Shape, Tol: Optional[float] = -1, OnlyPlane: Optional[bool] = False, OnlyClosed: Optional[bool] = False) -> None: ...
	def Location(self) -> TopLoc_Location: ...
	def Surface(self) -> Geom_Surface: ...
	def Tolerance(self) -> float: ...
	def ToleranceReached(self) -> float: ...

class BRepLib_FuseEdges:
	def __init__(self, theShape: TopoDS_Shape, PerformNow: Optional[bool] = False) -> None: ...
	def AvoidEdges(self, theMapEdg: TopTools_IndexedMapOfShape) -> None: ...
	def Edges(self, theMapLstEdg: TopTools_DataMapOfIntegerListOfShape) -> None: ...
	def Faces(self, theMapFac: TopTools_DataMapOfShapeShape) -> None: ...
	def NbVertices(self) -> int: ...
	def Perform(self) -> None: ...
	def ResultEdges(self, theMapEdg: TopTools_DataMapOfIntegerShape) -> None: ...
	def SetConcatBSpl(self, theConcatBSpl: Optional[bool] = True) -> None: ...
	def Shape(self) -> TopoDS_Shape: ...

class BRepLib_MakeShape(BRepLib_Command):
	def Build(self) -> None: ...
	def DescendantFaces(self, F: TopoDS_Face) -> TopTools_ListOfShape: ...
	def FaceStatus(self, F: TopoDS_Face) -> BRepLib_ShapeModification: ...
	def FacesFromEdges(self, E: TopoDS_Edge) -> TopTools_ListOfShape: ...
	def HasDescendants(self, F: TopoDS_Face) -> bool: ...
	def NbSurfaces(self) -> int: ...
	def NewFaces(self, I: int) -> TopTools_ListOfShape: ...
	def Shape(self) -> TopoDS_Shape: ...

class BRepLib_MakeEdge(BRepLib_MakeShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def __init__(self, L: gp_Lin) -> None: ...
	@overload
	def __init__(self, L: gp_Lin, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Lin, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def __init__(self, L: gp_Lin, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: gp_Circ) -> None: ...
	@overload
	def __init__(self, L: gp_Circ, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Circ, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def __init__(self, L: gp_Circ, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: gp_Elips) -> None: ...
	@overload
	def __init__(self, L: gp_Elips, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Elips, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def __init__(self, L: gp_Elips, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: gp_Hypr) -> None: ...
	@overload
	def __init__(self, L: gp_Hypr, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Hypr, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def __init__(self, L: gp_Hypr, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: gp_Parab) -> None: ...
	@overload
	def __init__(self, L: gp_Parab, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Parab, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def __init__(self, L: gp_Parab, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: Geom_Curve) -> None: ...
	@overload
	def __init__(self, L: Geom_Curve, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: Geom_Curve, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def __init__(self, L: Geom_Curve, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: Geom_Curve, P1: gp_Pnt, P2: gp_Pnt, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: Geom_Curve, V1: TopoDS_Vertex, V2: TopoDS_Vertex, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, S: Geom_Surface) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, S: Geom_Surface, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, S: Geom_Surface, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, S: Geom_Surface, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, S: Geom_Surface, P1: gp_Pnt, P2: gp_Pnt, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, S: Geom_Surface, V1: TopoDS_Vertex, V2: TopoDS_Vertex, p1: float, p2: float) -> None: ...
	def Edge(self) -> TopoDS_Edge: ...
	def Error(self) -> BRepLib_EdgeError: ...
	@overload
	def Init(self, C: Geom_Curve) -> None: ...
	@overload
	def Init(self, C: Geom_Curve, p1: float, p2: float) -> None: ...
	@overload
	def Init(self, C: Geom_Curve, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def Init(self, C: Geom_Curve, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def Init(self, C: Geom_Curve, P1: gp_Pnt, P2: gp_Pnt, p1: float, p2: float) -> None: ...
	@overload
	def Init(self, C: Geom_Curve, V1: TopoDS_Vertex, V2: TopoDS_Vertex, p1: float, p2: float) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, S: Geom_Surface) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, S: Geom_Surface, p1: float, p2: float) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, S: Geom_Surface, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, S: Geom_Surface, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, S: Geom_Surface, P1: gp_Pnt, P2: gp_Pnt, p1: float, p2: float) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, S: Geom_Surface, V1: TopoDS_Vertex, V2: TopoDS_Vertex, p1: float, p2: float) -> None: ...
	def Vertex1(self) -> TopoDS_Vertex: ...
	def Vertex2(self) -> TopoDS_Vertex: ...

class BRepLib_MakeEdge2d(BRepLib_MakeShape):
	@overload
	def __init__(self, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: gp_Circ2d) -> None: ...
	@overload
	def __init__(self, L: gp_Circ2d, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Circ2d, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, L: gp_Circ2d, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: gp_Elips2d) -> None: ...
	@overload
	def __init__(self, L: gp_Elips2d, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Elips2d, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, L: gp_Elips2d, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: gp_Hypr2d) -> None: ...
	@overload
	def __init__(self, L: gp_Hypr2d, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Hypr2d, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, L: gp_Hypr2d, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: gp_Parab2d) -> None: ...
	@overload
	def __init__(self, L: gp_Parab2d, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Parab2d, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, L: gp_Parab2d, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, P1: gp_Pnt2d, P2: gp_Pnt2d, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, V1: TopoDS_Vertex, V2: TopoDS_Vertex, p1: float, p2: float) -> None: ...
	def Edge(self) -> TopoDS_Edge: ...
	def Error(self) -> BRepLib_EdgeError: ...
	@overload
	def Init(self, C: Geom2d_Curve) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, p1: float, p2: float) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, P1: gp_Pnt2d, P2: gp_Pnt2d, p1: float, p2: float) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, V1: TopoDS_Vertex, V2: TopoDS_Vertex, p1: float, p2: float) -> None: ...
	def Vertex1(self) -> TopoDS_Vertex: ...
	def Vertex2(self) -> TopoDS_Vertex: ...

class BRepLib_MakeFace(BRepLib_MakeShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, F: TopoDS_Face) -> None: ...
	@overload
	def __init__(self, P: gp_Pln) -> None: ...
	@overload
	def __init__(self, C: gp_Cylinder) -> None: ...
	@overload
	def __init__(self, C: gp_Cone) -> None: ...
	@overload
	def __init__(self, S: gp_Sphere) -> None: ...
	@overload
	def __init__(self, C: gp_Torus) -> None: ...
	@overload
	def __init__(self, S: Geom_Surface, TolDegen: float) -> None: ...
	@overload
	def __init__(self, P: gp_Pln, UMin: float, UMax: float, VMin: float, VMax: float) -> None: ...
	@overload
	def __init__(self, C: gp_Cylinder, UMin: float, UMax: float, VMin: float, VMax: float) -> None: ...
	@overload
	def __init__(self, C: gp_Cone, UMin: float, UMax: float, VMin: float, VMax: float) -> None: ...
	@overload
	def __init__(self, S: gp_Sphere, UMin: float, UMax: float, VMin: float, VMax: float) -> None: ...
	@overload
	def __init__(self, C: gp_Torus, UMin: float, UMax: float, VMin: float, VMax: float) -> None: ...
	@overload
	def __init__(self, S: Geom_Surface, UMin: float, UMax: float, VMin: float, VMax: float, TolDegen: float) -> None: ...
	@overload
	def __init__(self, W: TopoDS_Wire, OnlyPlane: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, P: gp_Pln, W: TopoDS_Wire, Inside: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, C: gp_Cylinder, W: TopoDS_Wire, Inside: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, C: gp_Cone, W: TopoDS_Wire, Inside: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, S: gp_Sphere, W: TopoDS_Wire, Inside: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, C: gp_Torus, W: TopoDS_Wire, Inside: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, S: Geom_Surface, W: TopoDS_Wire, Inside: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, F: TopoDS_Face, W: TopoDS_Wire) -> None: ...
	def Add(self, W: TopoDS_Wire) -> None: ...
	def Error(self) -> BRepLib_FaceError: ...
	def Face(self) -> TopoDS_Face: ...
	@overload
	def Init(self, F: TopoDS_Face) -> None: ...
	@overload
	def Init(self, S: Geom_Surface, Bound: bool, TolDegen: float) -> None: ...
	@overload
	def Init(self, S: Geom_Surface, UMin: float, UMax: float, VMin: float, VMax: float, TolDegen: float) -> None: ...
	@staticmethod
	def IsDegenerated(theCurve: Geom_Curve, theMaxTol: float) -> Tuple[bool, float]: ...

class BRepLib_MakePolygon(BRepLib_MakeShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt, P3: gp_Pnt, Close: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt, P3: gp_Pnt, P4: gp_Pnt, Close: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, V1: TopoDS_Vertex, V2: TopoDS_Vertex, V3: TopoDS_Vertex, Close: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, V1: TopoDS_Vertex, V2: TopoDS_Vertex, V3: TopoDS_Vertex, V4: TopoDS_Vertex, Close: Optional[bool] = False) -> None: ...
	@overload
	def Add(self, P: gp_Pnt) -> None: ...
	@overload
	def Add(self, V: TopoDS_Vertex) -> None: ...
	def Added(self) -> bool: ...
	def Close(self) -> None: ...
	def Edge(self) -> TopoDS_Edge: ...
	def FirstVertex(self) -> TopoDS_Vertex: ...
	def LastVertex(self) -> TopoDS_Vertex: ...
	def Wire(self) -> TopoDS_Wire: ...

class BRepLib_MakeShell(BRepLib_MakeShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: Geom_Surface, Segment: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, S: Geom_Surface, UMin: float, UMax: float, VMin: float, VMax: float, Segment: Optional[bool] = False) -> None: ...
	def Error(self) -> BRepLib_ShellError: ...
	def Init(self, S: Geom_Surface, UMin: float, UMax: float, VMin: float, VMax: float, Segment: Optional[bool] = False) -> None: ...
	def Shell(self) -> TopoDS_Shell: ...

class BRepLib_MakeSolid(BRepLib_MakeShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_CompSolid) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shell) -> None: ...
	@overload
	def __init__(self, S1: TopoDS_Shell, S2: TopoDS_Shell) -> None: ...
	@overload
	def __init__(self, S1: TopoDS_Shell, S2: TopoDS_Shell, S3: TopoDS_Shell) -> None: ...
	@overload
	def __init__(self, So: TopoDS_Solid) -> None: ...
	@overload
	def __init__(self, So: TopoDS_Solid, S: TopoDS_Shell) -> None: ...
	def Add(self, S: TopoDS_Shell) -> None: ...
	def FaceStatus(self, F: TopoDS_Face) -> BRepLib_ShapeModification: ...
	def Solid(self) -> TopoDS_Solid: ...

class BRepLib_MakeVertex(BRepLib_MakeShape):
	@overload
	def __init__(self, P: gp_Pnt) -> None: ...
	def Vertex(self) -> TopoDS_Vertex: ...

class BRepLib_MakeWire(BRepLib_MakeShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, E: TopoDS_Edge) -> None: ...
	@overload
	def __init__(self, E1: TopoDS_Edge, E2: TopoDS_Edge) -> None: ...
	@overload
	def __init__(self, E1: TopoDS_Edge, E2: TopoDS_Edge, E3: TopoDS_Edge) -> None: ...
	@overload
	def __init__(self, E1: TopoDS_Edge, E2: TopoDS_Edge, E3: TopoDS_Edge, E4: TopoDS_Edge) -> None: ...
	@overload
	def __init__(self, W: TopoDS_Wire) -> None: ...
	@overload
	def __init__(self, W: TopoDS_Wire, E: TopoDS_Edge) -> None: ...
	@overload
	def Add(self, E: TopoDS_Edge) -> None: ...
	@overload
	def Add(self, W: TopoDS_Wire) -> None: ...
	@overload
	def Add(self, L: TopTools_ListOfShape) -> None: ...
	def Edge(self) -> TopoDS_Edge: ...
	def Error(self) -> BRepLib_WireError: ...
	def Vertex(self) -> TopoDS_Vertex: ...
	def Wire(self) -> TopoDS_Wire: ...

# harray1 classes
# harray2 classes
# hsequence classes

breplib_BoundingVertex = breplib.BoundingVertex
breplib_BuildCurve3d = breplib.BuildCurve3d
breplib_BuildCurves3d = breplib.BuildCurves3d
breplib_BuildCurves3d = breplib.BuildCurves3d
breplib_BuildPCurveForEdgeOnPlane = breplib.BuildPCurveForEdgeOnPlane
breplib_BuildPCurveForEdgeOnPlane = breplib.BuildPCurveForEdgeOnPlane
breplib_CheckSameRange = breplib.CheckSameRange
breplib_EncodeRegularity = breplib.EncodeRegularity
breplib_EncodeRegularity = breplib.EncodeRegularity
breplib_EncodeRegularity = breplib.EncodeRegularity
breplib_EnsureNormalConsistency = breplib.EnsureNormalConsistency
breplib_ExtendFace = breplib.ExtendFace
breplib_FindValidRange = breplib.FindValidRange
breplib_FindValidRange = breplib.FindValidRange
breplib_OrientClosedSolid = breplib.OrientClosedSolid
breplib_Plane = breplib.Plane
breplib_Plane = breplib.Plane
breplib_Precision = breplib.Precision
breplib_Precision = breplib.Precision
breplib_ReverseSortFaces = breplib.ReverseSortFaces
breplib_SameParameter = breplib.SameParameter
breplib_SameParameter = breplib.SameParameter
breplib_SameParameter = breplib.SameParameter
breplib_SameParameter = breplib.SameParameter
breplib_SameRange = breplib.SameRange
breplib_SortFaces = breplib.SortFaces
breplib_UpdateEdgeTol = breplib.UpdateEdgeTol
breplib_UpdateEdgeTolerance = breplib.UpdateEdgeTolerance
breplib_UpdateInnerTolerances = breplib.UpdateInnerTolerances
breplib_UpdateTolerances = breplib.UpdateTolerances
breplib_UpdateTolerances = breplib.UpdateTolerances
BRepLib_MakeFace_IsDegenerated = BRepLib_MakeFace.IsDegenerated



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.GeomAbs import *


class LProp_SequenceOfCIType:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> LProp_CIType: ...
    def Last(self) -> LProp_CIType: ...
    def Length(self) -> int: ...
    def Append(self, theItem: LProp_CIType) -> LProp_CIType: ...
    def Prepend(self, theItem: LProp_CIType) -> LProp_CIType: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> LProp_CIType: ...
    def SetValue(self, theIndex: int, theValue: LProp_CIType) -> None: ...

class LProp_Status(IntEnum):
	LProp_Undecided: int = ...
	LProp_Undefined: int = ...
	LProp_Defined: int = ...
	LProp_Computed: int = ...
LProp_Undecided = LProp_Status.LProp_Undecided
LProp_Undefined = LProp_Status.LProp_Undefined
LProp_Defined = LProp_Status.LProp_Defined
LProp_Computed = LProp_Status.LProp_Computed

class LProp_CIType(IntEnum):
	LProp_Inflection: int = ...
	LProp_MinCur: int = ...
	LProp_MaxCur: int = ...
LProp_Inflection = LProp_CIType.LProp_Inflection
LProp_MinCur = LProp_CIType.LProp_MinCur
LProp_MaxCur = LProp_CIType.LProp_MaxCur

class LProp_AnalyticCurInf:
	def __init__(self) -> None: ...
	def Perform(self, T: GeomAbs_CurveType, UFirst: float, ULast: float, Result: LProp_CurAndInf) -> None: ...

class LProp_CurAndInf:
	def __init__(self) -> None: ...
	def AddExtCur(self, Param: float, IsMin: bool) -> None: ...
	def AddInflection(self, Param: float) -> None: ...
	def Clear(self) -> None: ...
	def IsEmpty(self) -> bool: ...
	def NbPoints(self) -> int: ...
	def Parameter(self, N: int) -> float: ...
	def Type(self, N: int) -> LProp_CIType: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Geom import *
from OCC.Core.Prs3d import *
from OCC.Core.TCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.gp import *
from OCC.Core.Graphic3d import *
from OCC.Core.Adaptor3d import *
from OCC.Core.TColgp import *
from OCC.Core.HLRAlgo import *
from OCC.Core.BRepAdaptor import *
from OCC.Core.TColStd import *
from OCC.Core.Poly import *
from OCC.Core.TopLoc import *
from OCC.Core.BRep import *
from OCC.Core.GeomAbs import *
from OCC.Core.Bnd import *
from OCC.Core.TopTools import *
from OCC.Core.TopAbs import *
from OCC.Core.Adaptor2d import *

StdPrs_BndBox = NewType('StdPrs_BndBox', Prs3d_BndBox)
#the following typedef cannot be wrapped as is
StdPrs_Point = NewType('StdPrs_Point', Any)
#the following typedef cannot be wrapped as is
StdPrs_Vertex = NewType('StdPrs_Vertex', Any)

class StdPrs_Volume(IntEnum):
	StdPrs_Volume_Autodetection: int = ...
	StdPrs_Volume_Closed: int = ...
	StdPrs_Volume_Opened: int = ...
StdPrs_Volume_Autodetection = StdPrs_Volume.StdPrs_Volume_Autodetection
StdPrs_Volume_Closed = StdPrs_Volume.StdPrs_Volume_Closed
StdPrs_Volume_Opened = StdPrs_Volume.StdPrs_Volume_Opened

class StdPrs_BRepFont(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theFontPath: NCollection_String, theSize: float, theFaceId: Optional[int] = 0) -> None: ...
	@overload
	def AdvanceX(self, theUCharNext: Standard_Utf32Char) -> float: ...
	@overload
	def AdvanceX(self, theUChar: Standard_Utf32Char, theUCharNext: Standard_Utf32Char) -> float: ...
	@overload
	def AdvanceY(self, theUCharNext: Standard_Utf32Char) -> float: ...
	@overload
	def AdvanceY(self, theUChar: Standard_Utf32Char, theUCharNext: Standard_Utf32Char) -> float: ...
	def Ascender(self) -> float: ...
	def Descender(self) -> float: ...
	def FTFont(self) -> False: ...
	@overload
	def Init(self, theFontPath: NCollection_String, theSize: float, theFaceId: int) -> False: ...
	def LineSpacing(self) -> float: ...
	def Mutex(self) -> Standard_Mutex: ...
	def PointSize(self) -> float: ...
	def Release(self) -> None: ...
	def RenderGlyph(self, theChar: Standard_Utf32Char) -> TopoDS_Shape: ...
	def Scale(self) -> float: ...
	def SetCompositeCurveMode(self, theToConcatenate: bool) -> None: ...

class StdPrs_BRepTextBuilder:
	@overload
	def Perform(self, theFont: StdPrs_BRepFont, theString: NCollection_String, thePenLoc: Optional[gp_Ax3] = gp_Ax3(), theHAlign: Optional[Graphic3d_HorizontalTextAlignment] = Graphic3d_HTA_LEFT, theVAlign: Optional[Graphic3d_VerticalTextAlignment] = Graphic3d_VTA_BOTTOM) -> TopoDS_Shape: ...

class StdPrs_Curve(Prs3d_Root):
	@overload
	@staticmethod
	def Add(aPresentation: Prs3d_Presentation, aCurve: Adaptor3d_Curve, aDrawer: Prs3d_Drawer, drawCurve: Optional[bool] = True) -> None: ...
	@overload
	@staticmethod
	def Add(aPresentation: Prs3d_Presentation, aCurve: Adaptor3d_Curve, U1: float, U2: float, aDrawer: Prs3d_Drawer, drawCurve: Optional[bool] = True) -> None: ...
	@overload
	@staticmethod
	def Add(aPresentation: Prs3d_Presentation, aCurve: Adaptor3d_Curve, aDrawer: Prs3d_Drawer, Points: TColgp_SequenceOfPnt, drawCurve: Optional[bool] = True) -> None: ...
	@overload
	@staticmethod
	def Add(aPresentation: Prs3d_Presentation, aCurve: Adaptor3d_Curve, U1: float, U2: float, Points: TColgp_SequenceOfPnt, aNbPoints: Optional[int] = 30, drawCurve: Optional[bool] = True) -> None: ...
	@overload
	@staticmethod
	def Match(X: float, Y: float, Z: float, aDistance: float, aCurve: Adaptor3d_Curve, aDrawer: Prs3d_Drawer) -> bool: ...
	@overload
	@staticmethod
	def Match(X: float, Y: float, Z: float, aDistance: float, aCurve: Adaptor3d_Curve, aDeflection: float, aLimit: float, aNbPoints: int) -> bool: ...
	@overload
	@staticmethod
	def Match(X: float, Y: float, Z: float, aDistance: float, aCurve: Adaptor3d_Curve, U1: float, U2: float, aDrawer: Prs3d_Drawer) -> bool: ...
	@overload
	@staticmethod
	def Match(X: float, Y: float, Z: float, aDistance: float, aCurve: Adaptor3d_Curve, U1: float, U2: float, aDeflection: float, aNbPoints: int) -> bool: ...

class StdPrs_HLRShapeI(Standard_Transient):
	def ComputeHLR(self, thePrs: Prs3d_Presentation, theShape: TopoDS_Shape, theDrawer: Prs3d_Drawer, theProjector: Graphic3d_Camera) -> None: ...

class StdPrs_HLRToolShape:
	def __init__(self, TheShape: TopoDS_Shape, TheProjector: HLRAlgo_Projector) -> None: ...
	def Hidden(self, TheEdge: BRepAdaptor_Curve) -> Tuple[float, float]: ...
	def InitHidden(self, EdgeNumber: int) -> None: ...
	def InitVisible(self, EdgeNumber: int) -> None: ...
	def MoreHidden(self) -> bool: ...
	def MoreVisible(self) -> bool: ...
	def NbEdges(self) -> int: ...
	def NextHidden(self) -> None: ...
	def NextVisible(self) -> None: ...
	def Visible(self, TheEdge: BRepAdaptor_Curve) -> Tuple[float, float]: ...

class StdPrs_Isolines(Prs3d_Root):
	@overload
	@staticmethod
	def Add(thePresentation: Prs3d_Presentation, theFace: TopoDS_Face, theDrawer: Prs3d_Drawer, theDeflection: float) -> None: ...
	@overload
	@staticmethod
	def Add(theFace: TopoDS_Face, theDrawer: Prs3d_Drawer, theDeflection: float, theUPolylines: Prs3d_NListOfSequenceOfPnt, theVPolylines: Prs3d_NListOfSequenceOfPnt) -> None: ...
	@overload
	@staticmethod
	def AddOnSurface(thePresentation: Prs3d_Presentation, theFace: TopoDS_Face, theDrawer: Prs3d_Drawer, theDeflection: float) -> None: ...
	@overload
	@staticmethod
	def AddOnSurface(theFace: TopoDS_Face, theDrawer: Prs3d_Drawer, theDeflection: float, theUPolylines: Prs3d_NListOfSequenceOfPnt, theVPolylines: Prs3d_NListOfSequenceOfPnt) -> None: ...
	@overload
	@staticmethod
	def AddOnSurface(thePresentation: Prs3d_Presentation, theSurface: BRepAdaptor_HSurface, theDrawer: Prs3d_Drawer, theDeflection: float, theUIsoParams: TColStd_SequenceOfReal, theVIsoParams: TColStd_SequenceOfReal) -> None: ...
	@overload
	@staticmethod
	def AddOnTriangulation(thePresentation: Prs3d_Presentation, theFace: TopoDS_Face, theDrawer: Prs3d_Drawer) -> None: ...
	@overload
	@staticmethod
	def AddOnTriangulation(theFace: TopoDS_Face, theDrawer: Prs3d_Drawer, theUPolylines: Prs3d_NListOfSequenceOfPnt, theVPolylines: Prs3d_NListOfSequenceOfPnt) -> None: ...
	@overload
	@staticmethod
	def AddOnTriangulation(thePresentation: Prs3d_Presentation, theTriangulation: Poly_Triangulation, theSurface: Geom_Surface, theLocation: TopLoc_Location, theDrawer: Prs3d_Drawer, theUIsoParams: TColStd_SequenceOfReal, theVIsoParams: TColStd_SequenceOfReal) -> None: ...
	@staticmethod
	def UVIsoParameters(theFace: TopoDS_Face, theNbIsoU: int, theNbIsoV: int, theUVLimit: float, theUIsoParams: TColStd_SequenceOfReal, theVIsoParams: TColStd_SequenceOfReal) -> Tuple[float, float, float, float]: ...

class StdPrs_Plane(Prs3d_Root):
	@staticmethod
	def Add(aPresentation: Prs3d_Presentation, aPlane: Adaptor3d_Surface, aDrawer: Prs3d_Drawer) -> None: ...
	@staticmethod
	def Match(X: float, Y: float, Z: float, aDistance: float, aPlane: Adaptor3d_Surface, aDrawer: Prs3d_Drawer) -> bool: ...

class StdPrs_PoleCurve(Prs3d_Root):
	@staticmethod
	def Add(aPresentation: Prs3d_Presentation, aCurve: Adaptor3d_Curve, aDrawer: Prs3d_Drawer) -> None: ...
	@staticmethod
	def Match(X: float, Y: float, Z: float, aDistance: float, aCurve: Adaptor3d_Curve, aDrawer: Prs3d_Drawer) -> bool: ...
	@staticmethod
	def Pick(X: float, Y: float, Z: float, aDistance: float, aCurve: Adaptor3d_Curve, aDrawer: Prs3d_Drawer) -> int: ...

class StdPrs_ShadedShape(Prs3d_Root):
	@overload
	@staticmethod
	def Add(thePresentation: Prs3d_Presentation, theShape: TopoDS_Shape, theDrawer: Prs3d_Drawer, theVolume: Optional[StdPrs_Volume] = StdPrs_Volume_Autodetection) -> None: ...
	@overload
	@staticmethod
	def Add(thePresentation: Prs3d_Presentation, theShape: TopoDS_Shape, theDrawer: Prs3d_Drawer, theHasTexels: bool, theUVOrigin: gp_Pnt2d, theUVRepeat: gp_Pnt2d, theUVScale: gp_Pnt2d, theVolume: Optional[StdPrs_Volume] = StdPrs_Volume_Autodetection) -> None: ...
	@staticmethod
	def AddWireframeForFacesWithoutTriangles(thePrs: Prs3d_Presentation, theShape: TopoDS_Shape, theDrawer: Prs3d_Drawer) -> None: ...
	@staticmethod
	def AddWireframeForFreeElements(thePrs: Prs3d_Presentation, theShape: TopoDS_Shape, theDrawer: Prs3d_Drawer) -> None: ...
	@staticmethod
	def ExploreSolids(theShape: TopoDS_Shape, theBuilder: BRep_Builder, theClosed: TopoDS_Compound, theOpened: TopoDS_Compound, theIgnore1DSubShape: bool) -> None: ...
	@staticmethod
	def FillFaceBoundaries(theShape: TopoDS_Shape, theUpperContinuity: Optional[GeomAbs_Shape] = GeomAbs_CN) -> Graphic3d_ArrayOfSegments: ...
	@overload
	@staticmethod
	def FillTriangles(theShape: TopoDS_Shape) -> Graphic3d_ArrayOfTriangles: ...
	@overload
	@staticmethod
	def FillTriangles(theShape: TopoDS_Shape, theHasTexels: bool, theUVOrigin: gp_Pnt2d, theUVRepeat: gp_Pnt2d, theUVScale: gp_Pnt2d) -> Graphic3d_ArrayOfTriangles: ...

class StdPrs_ShadedSurface(Prs3d_Root):
	@staticmethod
	def Add(aPresentation: Prs3d_Presentation, aSurface: Adaptor3d_Surface, aDrawer: Prs3d_Drawer) -> None: ...

class StdPrs_ShapeTool:
	def __init__(self, theShape: TopoDS_Shape, theAllVertices: Optional[bool] = False) -> None: ...
	def CurrentTriangulation(self, l: TopLoc_Location) -> Poly_Triangulation: ...
	def CurveBound(self) -> Bnd_Box: ...
	def FaceBound(self) -> Bnd_Box: ...
	def FacesOfEdge(self) -> TopTools_HSequenceOfShape: ...
	def GetCurve(self) -> TopoDS_Edge: ...
	def GetFace(self) -> TopoDS_Face: ...
	def GetVertex(self) -> TopoDS_Vertex: ...
	def HasCurve(self) -> bool: ...
	def HasSurface(self) -> bool: ...
	def InitCurve(self) -> None: ...
	def InitFace(self) -> None: ...
	def InitVertex(self) -> None: ...
	@overload
	def IsPlanarFace(self) -> bool: ...
	@overload
	@staticmethod
	def IsPlanarFace(theFace: TopoDS_Face) -> bool: ...
	def MoreCurve(self) -> bool: ...
	def MoreFace(self) -> bool: ...
	def MoreVertex(self) -> bool: ...
	def Neighbours(self) -> int: ...
	def NextCurve(self) -> None: ...
	def NextFace(self) -> None: ...
	def NextVertex(self) -> None: ...
	def Polygon3D(self, l: TopLoc_Location) -> Poly_Polygon3D: ...
	def PolygonOnTriangulation(self, Indices: Poly_PolygonOnTriangulation, T: Poly_Triangulation, l: TopLoc_Location) -> None: ...

class StdPrs_ToolPoint:
	@staticmethod
	def Coord(aPoint: Geom_Point) -> Tuple[float, float, float]: ...

class StdPrs_ToolRFace:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aSurface: BRepAdaptor_HSurface) -> None: ...
	def Edge(self) -> TopoDS_Edge: ...
	def Init(self) -> None: ...
	def IsInvalidGeometry(self) -> bool: ...
	def IsOriented(self) -> bool: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Orientation(self) -> TopAbs_Orientation: ...
	def Value(self) -> Adaptor2d_Curve2d: ...

class StdPrs_ToolTriangulatedShape:
	@staticmethod
	def ClearOnOwnDeflectionChange(theShape: TopoDS_Shape, theDrawer: Prs3d_Drawer, theToResetCoeff: bool) -> None: ...
	@overload
	@staticmethod
	def ComputeNormals(theFace: TopoDS_Face, theTris: Poly_Triangulation) -> None: ...
	@overload
	@staticmethod
	def ComputeNormals(theFace: TopoDS_Face, theTris: Poly_Triangulation, thePolyConnect: Poly_Connect) -> None: ...
	@staticmethod
	def GetDeflection(theShape: TopoDS_Shape, theDrawer: Prs3d_Drawer) -> float: ...
	@staticmethod
	def IsClosed(theShape: TopoDS_Shape) -> bool: ...
	@staticmethod
	def IsTessellated(theShape: TopoDS_Shape, theDrawer: Prs3d_Drawer) -> bool: ...
	@staticmethod
	def IsTriangulated(theShape: TopoDS_Shape) -> bool: ...
	@staticmethod
	def Normal(theFace: TopoDS_Face, thePolyConnect: Poly_Connect, theNormals: TColgp_Array1OfDir) -> None: ...
	@staticmethod
	def Tessellate(theShape: TopoDS_Shape, theDrawer: Prs3d_Drawer) -> bool: ...

class StdPrs_ToolVertex:
	@staticmethod
	def Coord(aPoint: TopoDS_Vertex) -> Tuple[float, float, float]: ...

class StdPrs_WFDeflectionRestrictedFace(Prs3d_Root):
	@overload
	@staticmethod
	def Add(aPresentation: Prs3d_Presentation, aFace: BRepAdaptor_HSurface, aDrawer: Prs3d_Drawer) -> None: ...
	@overload
	@staticmethod
	def Add(aPresentation: Prs3d_Presentation, aFace: BRepAdaptor_HSurface, DrawUIso: bool, DrawVIso: bool, Deflection: float, NBUiso: int, NBViso: int, aDrawer: Prs3d_Drawer, Curves: Prs3d_NListOfSequenceOfPnt) -> None: ...
	@staticmethod
	def AddUIso(aPresentation: Prs3d_Presentation, aFace: BRepAdaptor_HSurface, aDrawer: Prs3d_Drawer) -> None: ...
	@staticmethod
	def AddVIso(aPresentation: Prs3d_Presentation, aFace: BRepAdaptor_HSurface, aDrawer: Prs3d_Drawer) -> None: ...
	@overload
	@staticmethod
	def Match(X: float, Y: float, Z: float, aDistance: float, aFace: BRepAdaptor_HSurface, aDrawer: Prs3d_Drawer) -> bool: ...
	@overload
	@staticmethod
	def Match(X: float, Y: float, Z: float, aDistance: float, aFace: BRepAdaptor_HSurface, aDrawer: Prs3d_Drawer, DrawUIso: bool, DrawVIso: bool, aDeflection: float, NBUiso: int, NBViso: int) -> bool: ...
	@staticmethod
	def MatchUIso(X: float, Y: float, Z: float, aDistance: float, aFace: BRepAdaptor_HSurface, aDrawer: Prs3d_Drawer) -> bool: ...
	@staticmethod
	def MatchVIso(X: float, Y: float, Z: float, aDistance: float, aFace: BRepAdaptor_HSurface, aDrawer: Prs3d_Drawer) -> bool: ...

class StdPrs_WFDeflectionSurface(Prs3d_Root):
	@staticmethod
	def Add(aPresentation: Prs3d_Presentation, aSurface: Adaptor3d_HSurface, aDrawer: Prs3d_Drawer) -> None: ...

class StdPrs_WFPoleSurface(Prs3d_Root):
	@staticmethod
	def Add(aPresentation: Prs3d_Presentation, aSurface: Adaptor3d_Surface, aDrawer: Prs3d_Drawer) -> None: ...

class StdPrs_WFRestrictedFace(Prs3d_Root):
	@overload
	@staticmethod
	def Add(thePresentation: Prs3d_Presentation, theFace: BRepAdaptor_HSurface, theDrawUIso: bool, theDrawVIso: bool, theNbUIso: int, theNbVIso: int, theDrawer: Prs3d_Drawer, theCurves: Prs3d_NListOfSequenceOfPnt) -> None: ...
	@overload
	@staticmethod
	def Add(thePresentation: Prs3d_Presentation, theFace: BRepAdaptor_HSurface, theDrawer: Prs3d_Drawer) -> None: ...
	@staticmethod
	def AddUIso(thePresentation: Prs3d_Presentation, theFace: BRepAdaptor_HSurface, theDrawer: Prs3d_Drawer) -> None: ...
	@staticmethod
	def AddVIso(thePresentation: Prs3d_Presentation, theFace: BRepAdaptor_HSurface, theDrawer: Prs3d_Drawer) -> None: ...
	@overload
	@staticmethod
	def Match(theX: float, theY: float, theZ: float, theDistance: float, theFace: BRepAdaptor_HSurface, theDrawUIso: bool, theDrawVIso: bool, theDeflection: float, theNbUIso: int, theNbVIso: int, theDrawer: Prs3d_Drawer) -> bool: ...
	@overload
	@staticmethod
	def Match(theX: float, theY: float, theZ: float, theDistance: float, theFace: BRepAdaptor_HSurface, theDrawer: Prs3d_Drawer) -> bool: ...
	@staticmethod
	def MatchUIso(theX: float, theY: float, theZ: float, theDistance: float, theFace: BRepAdaptor_HSurface, theDrawer: Prs3d_Drawer) -> bool: ...
	@staticmethod
	def MatchVIso(theX: float, theY: float, theZ: float, theDistance: float, theFace: BRepAdaptor_HSurface, theDrawer: Prs3d_Drawer) -> bool: ...

class StdPrs_WFShape(Prs3d_Root):
	@staticmethod
	def Add(thePresentation: Prs3d_Presentation, theShape: TopoDS_Shape, theDrawer: Prs3d_Drawer, theIsParallel: Optional[bool] = False) -> None: ...
	@staticmethod
	def AddAllEdges(theShape: TopoDS_Shape, theDrawer: Prs3d_Drawer) -> Graphic3d_ArrayOfPrimitives: ...
	@overload
	@staticmethod
	def AddEdgesOnTriangulation(theShape: TopoDS_Shape, theToExcludeGeometric: Optional[bool] = True) -> Graphic3d_ArrayOfPrimitives: ...
	@overload
	@staticmethod
	def AddEdgesOnTriangulation(theSegments: TColgp_SequenceOfPnt, theShape: TopoDS_Shape, theToExcludeGeometric: Optional[bool] = True) -> None: ...
	@staticmethod
	def AddVertexes(theShape: TopoDS_Shape, theVertexMode: Prs3d_VertexDrawMode) -> Graphic3d_ArrayOfPoints: ...

class StdPrs_WFSurface(Prs3d_Root):
	@staticmethod
	def Add(aPresentation: Prs3d_Presentation, aSurface: Adaptor3d_HSurface, aDrawer: Prs3d_Drawer) -> None: ...

class StdPrs_HLRPolyShape(StdPrs_HLRShapeI):
	def ComputeHLR(self, thePrs: Prs3d_Presentation, theShape: TopoDS_Shape, theDrawer: Prs3d_Drawer, theProjector: Graphic3d_Camera) -> None: ...

class StdPrs_HLRShape(StdPrs_HLRShapeI):
	def ComputeHLR(self, thePrs: Prs3d_Presentation, theShape: TopoDS_Shape, theDrawer: Prs3d_Drawer, theProjector: Graphic3d_Camera) -> None: ...

#classnotwrapped
class StdPrs_DeflectionCurve: ...

# harray1 classes
# harray2 classes
# hsequence classes

StdPrs_BRepFont_FindAndCreate = StdPrs_BRepFont.FindAndCreate
StdPrs_Curve_Add = StdPrs_Curve.Add
StdPrs_Curve_Add = StdPrs_Curve.Add
StdPrs_Curve_Add = StdPrs_Curve.Add
StdPrs_Curve_Add = StdPrs_Curve.Add
StdPrs_Curve_Match = StdPrs_Curve.Match
StdPrs_Curve_Match = StdPrs_Curve.Match
StdPrs_Curve_Match = StdPrs_Curve.Match
StdPrs_Curve_Match = StdPrs_Curve.Match
StdPrs_Isolines_Add = StdPrs_Isolines.Add
StdPrs_Isolines_Add = StdPrs_Isolines.Add
StdPrs_Isolines_AddOnSurface = StdPrs_Isolines.AddOnSurface
StdPrs_Isolines_AddOnSurface = StdPrs_Isolines.AddOnSurface
StdPrs_Isolines_AddOnSurface = StdPrs_Isolines.AddOnSurface
StdPrs_Isolines_AddOnTriangulation = StdPrs_Isolines.AddOnTriangulation
StdPrs_Isolines_AddOnTriangulation = StdPrs_Isolines.AddOnTriangulation
StdPrs_Isolines_AddOnTriangulation = StdPrs_Isolines.AddOnTriangulation
StdPrs_Isolines_UVIsoParameters = StdPrs_Isolines.UVIsoParameters
StdPrs_Plane_Add = StdPrs_Plane.Add
StdPrs_Plane_Match = StdPrs_Plane.Match
StdPrs_PoleCurve_Add = StdPrs_PoleCurve.Add
StdPrs_PoleCurve_Match = StdPrs_PoleCurve.Match
StdPrs_PoleCurve_Pick = StdPrs_PoleCurve.Pick
StdPrs_ShadedShape_Add = StdPrs_ShadedShape.Add
StdPrs_ShadedShape_Add = StdPrs_ShadedShape.Add
StdPrs_ShadedShape_AddWireframeForFacesWithoutTriangles = StdPrs_ShadedShape.AddWireframeForFacesWithoutTriangles
StdPrs_ShadedShape_AddWireframeForFreeElements = StdPrs_ShadedShape.AddWireframeForFreeElements
StdPrs_ShadedShape_ExploreSolids = StdPrs_ShadedShape.ExploreSolids
StdPrs_ShadedShape_FillFaceBoundaries = StdPrs_ShadedShape.FillFaceBoundaries
StdPrs_ShadedShape_FillTriangles = StdPrs_ShadedShape.FillTriangles
StdPrs_ShadedShape_FillTriangles = StdPrs_ShadedShape.FillTriangles
StdPrs_ShadedSurface_Add = StdPrs_ShadedSurface.Add
StdPrs_ShapeTool_IsPlanarFace = StdPrs_ShapeTool.IsPlanarFace
StdPrs_ToolPoint_Coord = StdPrs_ToolPoint.Coord
StdPrs_ToolTriangulatedShape_ClearOnOwnDeflectionChange = StdPrs_ToolTriangulatedShape.ClearOnOwnDeflectionChange
StdPrs_ToolTriangulatedShape_ComputeNormals = StdPrs_ToolTriangulatedShape.ComputeNormals
StdPrs_ToolTriangulatedShape_ComputeNormals = StdPrs_ToolTriangulatedShape.ComputeNormals
StdPrs_ToolTriangulatedShape_GetDeflection = StdPrs_ToolTriangulatedShape.GetDeflection
StdPrs_ToolTriangulatedShape_IsClosed = StdPrs_ToolTriangulatedShape.IsClosed
StdPrs_ToolTriangulatedShape_IsTessellated = StdPrs_ToolTriangulatedShape.IsTessellated
StdPrs_ToolTriangulatedShape_IsTriangulated = StdPrs_ToolTriangulatedShape.IsTriangulated
StdPrs_ToolTriangulatedShape_Normal = StdPrs_ToolTriangulatedShape.Normal
StdPrs_ToolTriangulatedShape_Tessellate = StdPrs_ToolTriangulatedShape.Tessellate
StdPrs_ToolVertex_Coord = StdPrs_ToolVertex.Coord
StdPrs_WFDeflectionRestrictedFace_Add = StdPrs_WFDeflectionRestrictedFace.Add
StdPrs_WFDeflectionRestrictedFace_Add = StdPrs_WFDeflectionRestrictedFace.Add
StdPrs_WFDeflectionRestrictedFace_AddUIso = StdPrs_WFDeflectionRestrictedFace.AddUIso
StdPrs_WFDeflectionRestrictedFace_AddVIso = StdPrs_WFDeflectionRestrictedFace.AddVIso
StdPrs_WFDeflectionRestrictedFace_Match = StdPrs_WFDeflectionRestrictedFace.Match
StdPrs_WFDeflectionRestrictedFace_Match = StdPrs_WFDeflectionRestrictedFace.Match
StdPrs_WFDeflectionRestrictedFace_MatchUIso = StdPrs_WFDeflectionRestrictedFace.MatchUIso
StdPrs_WFDeflectionRestrictedFace_MatchVIso = StdPrs_WFDeflectionRestrictedFace.MatchVIso
StdPrs_WFDeflectionSurface_Add = StdPrs_WFDeflectionSurface.Add
StdPrs_WFPoleSurface_Add = StdPrs_WFPoleSurface.Add
StdPrs_WFRestrictedFace_Add = StdPrs_WFRestrictedFace.Add
StdPrs_WFRestrictedFace_Add = StdPrs_WFRestrictedFace.Add
StdPrs_WFRestrictedFace_AddUIso = StdPrs_WFRestrictedFace.AddUIso
StdPrs_WFRestrictedFace_AddVIso = StdPrs_WFRestrictedFace.AddVIso
StdPrs_WFRestrictedFace_Match = StdPrs_WFRestrictedFace.Match
StdPrs_WFRestrictedFace_Match = StdPrs_WFRestrictedFace.Match
StdPrs_WFRestrictedFace_MatchUIso = StdPrs_WFRestrictedFace.MatchUIso
StdPrs_WFRestrictedFace_MatchVIso = StdPrs_WFRestrictedFace.MatchVIso
StdPrs_WFShape_Add = StdPrs_WFShape.Add
StdPrs_WFShape_AddAllEdges = StdPrs_WFShape.AddAllEdges
StdPrs_WFShape_AddEdgesOnTriangulation = StdPrs_WFShape.AddEdgesOnTriangulation
StdPrs_WFShape_AddEdgesOnTriangulation = StdPrs_WFShape.AddEdgesOnTriangulation
StdPrs_WFShape_AddVertexes = StdPrs_WFShape.AddVertexes
StdPrs_WFSurface_Add = StdPrs_WFSurface.Add



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TCollection import *
from OCC.Core.Image import *
from OCC.Core.Graphic3d import *


class Media_BufferPool(Standard_Transient):
	def __init__(self) -> None: ...
	def BufferSize(self) -> False: ...
	def GetBuffer(self) -> False: ...
	def Release(self) -> None: ...

class Media_CodecContext(Standard_Transient):
	def __init__(self) -> None: ...
	def CanProcessPacket(self, thePacket: Media_Packet) -> False: ...
	def Close(self) -> None: ...
	def Context(self) -> False: ...
	def Flush(self) -> None: ...
	def ReceiveFrame(self, theFrame: Media_Frame) -> False: ...
	def SendPacket(self, thePacket: Media_Packet) -> False: ...
	def SizeX(self) -> False: ...
	def SizeY(self) -> False: ...
	def StreamIndex(self) -> False: ...

class Media_FormatContext(Standard_Transient):
	def __init__(self) -> None: ...
	def Close(self) -> None: ...
	def Context(self) -> False: ...
	def Duration(self) -> False: ...
	def NbSteams(self) -> int: ...
	def OpenInput(self, theInput: TCollection_AsciiString) -> False: ...
	def PtsStartBase(self) -> False: ...
	def ReadPacket(self, thePacket: Media_Packet) -> False: ...
	def Stream(self, theIndex: int) -> False: ...

class Media_Frame(Standard_Transient):
	def __init__(self) -> None: ...
	def BestEffortTimestamp(self) -> False: ...
	def ChangeFrame(self) -> False: ...
	def Format(self) -> False: ...
	@staticmethod
	def FormatOcct2FFmpeg(theFormat: Image_Format) -> int: ...
	def Frame(self) -> False: ...
	def InitWrapper(self, thePixMap: Image_PixMap) -> False: ...
	def IsEmpty(self) -> False: ...
	def IsFullRangeYUV(self) -> False: ...
	def IsLocked(self) -> False: ...
	def PixelAspectRatio(self) -> False: ...
	def Pts(self) -> False: ...
	def Size(self) -> Graphic3d_Vec2i: ...
	def SizeX(self) -> False: ...
	def SizeY(self) -> False: ...
	@staticmethod
	def Swap(theFrame1: Media_Frame, theFrame2: Media_Frame) -> None: ...
	def Unref(self) -> None: ...

class Media_IFrameQueue:
	def LockFrame(self) -> Media_Frame: ...
	def ReleaseFrame(self, theFrame: Media_Frame) -> None: ...

class Media_Packet(Standard_Transient):
	def __init__(self) -> None: ...
	def ChangeData(self) -> False: ...
	def ChangePacket(self) -> False: ...
	def Data(self) -> False: ...
	def Dts(self) -> False: ...
	def Duration(self) -> False: ...
	def DurationSeconds(self) -> False: ...
	def IsKeyFrame(self) -> False: ...
	def Packet(self) -> False: ...
	def Pts(self) -> False: ...
	def SetKeyFrame(self) -> None: ...
	def Size(self) -> False: ...
	def StreamIndex(self) -> False: ...
	def Unref(self) -> None: ...

class Media_PlayerContext(Standard_Transient):
	def __init__(self, theFrameQueue: Media_IFrameQueue) -> None: ...
	@overload
	@staticmethod
	def DumpFirstFrame(theSrcVideo: TCollection_AsciiString, theMediaInfo: TCollection_AsciiString) -> Media_Frame: ...
	def Pause(self) -> None: ...
	def PlayPause(self) -> Tuple[bool, float, float]: ...
	def PlaybackState(self) -> Tuple[bool, float, float]: ...
	def Resume(self) -> None: ...
	def Seek(self, thePosSec: float) -> None: ...
	def SetInput(self, theInputPath: TCollection_AsciiString, theToWait: bool) -> None: ...
	def ToForceRgb(self) -> False: ...

class Media_Scaler(Standard_Transient):
	def __init__(self) -> None: ...
	def Convert(self, theSrc: Media_Frame, theRes: Media_Frame) -> False: ...
	def IsValid(self) -> False: ...
	def Release(self) -> None: ...

class Media_Timer(Standard_Transient):
	def __init__(self) -> None: ...
	def ElapsedTime(self) -> float: ...
	def IsStarted(self) -> bool: ...
	def Pause(self) -> None: ...
	def PlaybackSpeed(self) -> float: ...
	def Seek(self, theTime: float) -> None: ...
	def SetPlaybackSpeed(self, theSpeed: float) -> None: ...
	def Start(self) -> None: ...
	def Stop(self) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

Media_FormatContext_FormatAVErrorDescription = Media_FormatContext.FormatAVErrorDescription
Media_FormatContext_FormatTime = Media_FormatContext.FormatTime
Media_FormatContext_FormatTimeProgress = Media_FormatContext.FormatTimeProgress
Media_FormatContext_FormatUnitsToSeconds = Media_FormatContext.FormatUnitsToSeconds
Media_FormatContext_SecondsToUnits = Media_FormatContext.SecondsToUnits
Media_FormatContext_SecondsToUnits = Media_FormatContext.SecondsToUnits
Media_FormatContext_StreamSecondsToUnits = Media_FormatContext.StreamSecondsToUnits
Media_FormatContext_StreamUnitsToSeconds = Media_FormatContext.StreamUnitsToSeconds
Media_FormatContext_UnitsToSeconds = Media_FormatContext.UnitsToSeconds
Media_Frame_FormatFFmpeg2Occt = Media_Frame.FormatFFmpeg2Occt
Media_Frame_FormatOcct2FFmpeg = Media_Frame.FormatOcct2FFmpeg
Media_Frame_Swap = Media_Frame.Swap
Media_PlayerContext_DumpFirstFrame = Media_PlayerContext.DumpFirstFrame
Media_PlayerContext_DumpFirstFrame = Media_PlayerContext.DumpFirstFrame



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
IntAna2d module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_intana2d.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _IntAna2d
else:
    import _IntAna2d

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _IntAna2d.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _IntAna2d.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IntAna2d.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IntAna2d.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _IntAna2d.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _IntAna2d.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _IntAna2d.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _IntAna2d.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _IntAna2d.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _IntAna2d.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IntAna2d.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _IntAna2d.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _IntAna2d.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IntAna2d.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IntAna2d.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IntAna2d.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _IntAna2d.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _IntAna2d:
_IntAna2d.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _IntAna2d.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection

from enum import IntEnum
from OCC.Core.Exception import *



class IntAna2d_AnaIntersection(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor. isdone returns false.

        Returns
        -------
        None
        Intersection between two lines.

        Parameters
        ----------
        L1: gp_Lin2d
        L2: gp_Lin2d

        Returns
        -------
        None
        Intersection between two circles.

        Parameters
        ----------
        C1: gp_Circ2d
        C2: gp_Circ2d

        Returns
        -------
        None
        Intersection between a line and a circle.

        Parameters
        ----------
        L: gp_Lin2d
        C: gp_Circ2d

        Returns
        -------
        None
        Intersection between a line and a conic.

        Parameters
        ----------
        L: gp_Lin2d
        C: IntAna2d_Conic

        Returns
        -------
        None
        Intersection between a circle and another conic.

        Parameters
        ----------
        C: gp_Circ2d
        Co: IntAna2d_Conic

        Returns
        -------
        None
        Intersection between an ellipse and another conic.

        Parameters
        ----------
        E: gp_Elips2d
        C: IntAna2d_Conic

        Returns
        -------
        None
        Intersection between a parabola and another conic.

        Parameters
        ----------
        P: gp_Parab2d
        C: IntAna2d_Conic

        Returns
        -------
        None
        Intersection between an hyperbola and another conic.

        Parameters
        ----------
        H: gp_Hypr2d
        C: IntAna2d_Conic

        Returns
        -------
        None

        """
        _IntAna2d.IntAna2d_AnaIntersection_swiginit(self, _IntAna2d.new_IntAna2d_AnaIntersection(*args))

    def IdenticalElements(self, *args) -> "Standard_Boolean":
        r"""
        For the intersection between an element of gp and a conic known by an implicit equation, the result will be true if the element of gp verifies the implicit equation. for the intersection between two lin2d or two circ2d, the result will be true if the elements are identical. the function returns false in all the other cases.

        Returns
        -------
        bool

        """
        return _IntAna2d.IntAna2d_AnaIntersection_IdenticalElements(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the computation was succesfull.

        Returns
        -------
        bool

        """
        return _IntAna2d.IntAna2d_AnaIntersection_IsDone(self, *args)

    def IsEmpty(self, *args) -> "Standard_Boolean":
        r"""
        Returns true when there is no intersection, i-e - no intersection point - the elements are not identical. the element may be parallel in this case.

        Returns
        -------
        bool

        """
        return _IntAna2d.IntAna2d_AnaIntersection_IsEmpty(self, *args)

    def NbPoints(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of intpoint between the 2 curves.

        Returns
        -------
        int

        """
        return _IntAna2d.IntAna2d_AnaIntersection_NbPoints(self, *args)

    def ParallelElements(self, *args) -> "Standard_Boolean":
        r"""
        For the intersection between two lin2d or two circ2d, the function returns true if the elements are parallel. the function returns false in all the other cases.

        Returns
        -------
        bool

        """
        return _IntAna2d.IntAna2d_AnaIntersection_ParallelElements(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Intersection between two lines.

        Parameters
        ----------
        L1: gp_Lin2d
        L2: gp_Lin2d

        Returns
        -------
        None
        Intersection between two circles.

        Parameters
        ----------
        C1: gp_Circ2d
        C2: gp_Circ2d

        Returns
        -------
        None
        Intersection between a line and a circle.

        Parameters
        ----------
        L: gp_Lin2d
        C: gp_Circ2d

        Returns
        -------
        None
        Intersection between a line and a conic.

        Parameters
        ----------
        L: gp_Lin2d
        C: IntAna2d_Conic

        Returns
        -------
        None
        Intersection between a circle and another conic.

        Parameters
        ----------
        C: gp_Circ2d
        Co: IntAna2d_Conic

        Returns
        -------
        None
        Intersection between an ellipse and another conic.

        Parameters
        ----------
        E: gp_Elips2d
        C: IntAna2d_Conic

        Returns
        -------
        None
        Intersection between a parabola and another conic.

        Parameters
        ----------
        P: gp_Parab2d
        C: IntAna2d_Conic

        Returns
        -------
        None
        Intersection between an hyperbola and another conic.

        Parameters
        ----------
        H: gp_Hypr2d
        C: IntAna2d_Conic

        Returns
        -------
        None

        """
        return _IntAna2d.IntAna2d_AnaIntersection_Perform(self, *args)

    def Point(self, *args) -> "IntAna2d_IntPoint const &":
        r"""
        Returns the intersection point of range n; if (n<=0) or (n>nbpoints), an exception is raised.

        Parameters
        ----------
        N: int

        Returns
        -------
        IntAna2d_IntPoint

        """
        return _IntAna2d.IntAna2d_AnaIntersection_Point(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IntAna2d.delete_IntAna2d_AnaIntersection

# Register IntAna2d_AnaIntersection in _IntAna2d:
_IntAna2d.IntAna2d_AnaIntersection_swigregister(IntAna2d_AnaIntersection)

class IntAna2d_Conic(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        C: gp_Circ2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: gp_Lin2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: gp_Parab2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: gp_Hypr2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: gp_Elips2d

        Returns
        -------
        None

        """
        _IntAna2d.IntAna2d_Conic_swiginit(self, _IntAna2d.new_IntAna2d_Conic(*args))

    def Coefficients(self, *args) -> "void":
        r"""
        Returns the coefficients of the polynomial equation wich defines the conic: a.x**2 + b.y**2 + 2.c.x*y + 2.d.x + 2.e.y + f = 0.

        Parameters
        ----------

        Returns
        -------
        A: float
        B: float
        C: float
        D: float
        E: float
        F: float

        """
        return _IntAna2d.IntAna2d_Conic_Coefficients(self, *args)

    def Grad(self, *args) -> "gp_XY":
        r"""
        Returns the value of the gradient of f at the point x,y.

        Parameters
        ----------
        X: float
        Y: float

        Returns
        -------
        gp_XY

        """
        return _IntAna2d.IntAna2d_Conic_Grad(self, *args)

    def NewCoefficients(self, *args) -> "void":
        r"""
        Returns the coefficients of the polynomial equation ( written in the natural coordinates system ) a x x + b y y + 2 c x y + 2 d x + 2 e y + f in the local coordinates system defined by axis.

        Parameters
        ----------
        Axis: gp_Ax2d

        Returns
        -------
        A: float
        B: float
        C: float
        D: float
        E: float
        F: float

        """
        return _IntAna2d.IntAna2d_Conic_NewCoefficients(self, *args)

    def ValAndGrad(self, *args) -> "void":
        r"""
        Returns the value of the function and its gradient at the point x,y.

        Parameters
        ----------
        X: float
        Y: float
        Grd: gp_XY

        Returns
        -------
        Val: float

        """
        return _IntAna2d.IntAna2d_Conic_ValAndGrad(self, *args)

    def Value(self, *args) -> "Standard_Real":
        r"""
        Value of the function f at the point x,y.

        Parameters
        ----------
        X: float
        Y: float

        Returns
        -------
        float

        """
        return _IntAna2d.IntAna2d_Conic_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IntAna2d.delete_IntAna2d_Conic

# Register IntAna2d_Conic in _IntAna2d:
_IntAna2d.IntAna2d_Conic_swigregister(IntAna2d_Conic)

class IntAna2d_IntPoint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Create an intersection point between 2 parametric 2d lines. x,y are the coordinate of the point. u1 is the parameter on the first element, u2 the parameter on the second one.

        Parameters
        ----------
        X: float
        Y: float
        U1: float
        U2: float

        Returns
        -------
        None
        Create an intersection point between a parametric 2d line, and a line given by an implicit equation (implicitcurve). x,y are the coordinate of the point. u1 is the parameter on the parametric element. empty constructor. it's necessary to use one of the setvalue method after this one.

        Parameters
        ----------
        X: float
        Y: float
        U1: float

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        None

        """
        _IntAna2d.IntAna2d_IntPoint_swiginit(self, _IntAna2d.new_IntAna2d_IntPoint(*args))

    def ParamOnFirst(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter on the first element.

        Returns
        -------
        float

        """
        return _IntAna2d.IntAna2d_IntPoint_ParamOnFirst(self, *args)

    def ParamOnSecond(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter on the second element. if the second element is an implicit curve, an exception is raised.

        Returns
        -------
        float

        """
        return _IntAna2d.IntAna2d_IntPoint_ParamOnSecond(self, *args)

    def SecondIsImplicit(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the second curve is implicit.

        Returns
        -------
        bool

        """
        return _IntAna2d.IntAna2d_IntPoint_SecondIsImplicit(self, *args)

    def SetValue(self, *args) -> "void":
        r"""
        Set the values for a 'non-implicit' point.

        Parameters
        ----------
        X: float
        Y: float
        U1: float
        U2: float

        Returns
        -------
        None
        Set the values for an 'implicit' point.

        Parameters
        ----------
        X: float
        Y: float
        U1: float

        Returns
        -------
        None

        """
        return _IntAna2d.IntAna2d_IntPoint_SetValue(self, *args)

    def Value(self, *args) -> "gp_Pnt2d const":
        r"""
        Returns the geometric point.

        Returns
        -------
        gp_Pnt2d

        """
        return _IntAna2d.IntAna2d_IntPoint_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IntAna2d.delete_IntAna2d_IntPoint

# Register IntAna2d_IntPoint in _IntAna2d:
_IntAna2d.IntAna2d_IntPoint_swigregister(IntAna2d_IntPoint)





